abcpmc Package
==============

:mod:`sampler` Module
---------------------

.. autoclass:: abcpmc.sampler.Sampler
   :members: 

.. autoclass:: abcpmc.sampler.GaussianPrior
   :members: 

.. autoclass:: abcpmc.sampler.TophatPrior
   :members: 

.. autoclass:: abcpmc.sampler.ParticleProposal
   :members: 

.. autoclass:: abcpmc.sampler.OLCMParticleProposal
   :members: 
   :show-inheritance:

.. autoclass:: abcpmc.sampler.KNNParticleProposal
   :members: 
   :show-inheritance:

.. autofunction:: abcpmc.sampler.weighted_cov

.. autofunction:: abcpmc.sampler.weighted_avg_and_std

:mod:`threshold` Module
-----------------------

Various different threshold implementations

.. automodule:: abcpmc.threshold
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`mpi_util` Module
----------------------

A helper util for message passing interface (MPI) handlings

.. automodule:: abcpmc.mpi_util
    :members:
    :undoc-members:
    :show-inheritance:

